@@ -27,6 +27,8 @@ const int HISWIDTH = 451; //历史记录宽度
 SimpleListDelegate::SimpleListDelegate(int mode, QObject *parent)
     : QStyledItemDelegate(parent)
 {
+    qDebug() << "SimpleListDelegate constructor, mode:" << mode;
+
     m_mode = mode;
     m_selected = false;
     m_simpleListDelegate = this;
@@ -34,6 +36,7 @@ SimpleListDelegate::SimpleListDelegate(int mode, QObject *parent)
 
 SimpleListDelegate::~SimpleListDelegate()
 {
+    qDebug() << "SimpleListDelegate destructor";
 //    delete m_simpleListDelegate;
 //    m_simpleListDelegate = NULL;
 }
@@ -111,6 +114,8 @@ void SimpleListDelegate::removeHisLinked()
 
 void SimpleListDelegate::setThemeType(int type)
 {
+    qDebug() << "SimpleListDelegate theme type changed to:" << type;
+
     m_type = type;
 }
 
@@ -127,6 +132,8 @@ void SimpleListDelegate::paintback(const QModelIndex &index, int state)
 
 void SimpleListDelegate::currentfocusindex(QModelIndex index)
 {
+    qDebug() << "SimpleListDelegate focus index changed to:" << index.row();
+
     m_focusindex = index;
 }
 
@@ -353,6 +360,8 @@ void SimpleListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
  */
 void SimpleListDelegate::drawFocusStatus(QPainter *painter, const QStyleOptionViewItem &option) const
 {
+    qDebug() << "SimpleListDelegate::drawFocusStatus";
+
     SimpleListView *listview = qobject_cast<SimpleListView *>(option.styleObject);
     if (listview->hasFocus()) {
         painter->setRenderHint(QPainter::Antialiasing, true);
@@ -460,6 +469,8 @@ void SimpleListDelegate::cutApart(const QString text, QString &linkNum, QString
  */
 void SimpleListDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+    qDebug() << "SimpleListDelegate::updateEditorGeometry";
+
     Q_UNUSED(index);
     editor->setGeometry(option.rect);
 }
