@@ -24,6 +24,8 @@ const int INPUTEDIT_HEIGHT = 55;
 SciExpressionBar::SciExpressionBar(QWidget *parent)
     : DWidget(parent)
 {
+    qDebug() << "SciExpressionBar constructor called";
+
     m_listView = new SimpleListView(0, this);
     m_listDelegate = new SimpleListDelegate(0, this);
     m_listModel = new SimpleListModel(0, this);
@@ -63,7 +65,10 @@ SciExpressionBar::SciExpressionBar(QWidget *parent)
                  };
 }
 
-SciExpressionBar::~SciExpressionBar() {}
+SciExpressionBar::~SciExpressionBar()
+{
+    qDebug() << "SciExpressionBar destructor called";
+}
 
 void SciExpressionBar::mouseMoveEvent(QMouseEvent *e)
 {
@@ -85,6 +90,7 @@ Quantity SciExpressionBar::getanswer()
 
 void SciExpressionBar::enterNumberEvent(const QString &text)
 {
+    qDebug() << "enterNumberEvent called with text:" << text;
     if (!judgeinput())
         return;
     if (m_inputNumber && m_isResult == true) {
@@ -136,6 +142,7 @@ void SciExpressionBar::enterNumberEvent(const QString &text)
 
 void SciExpressionBar::enterSymbolEvent(const QString &text)
 {
+    qDebug() << "enterSymbolEvent called with text:" << text;
     if (!judgeinput())
         return;
     QString oldText = m_inputEdit->text();
@@ -204,6 +211,7 @@ void SciExpressionBar::enterSymbolEvent(const QString &text)
 
 void SciExpressionBar::enterPercentEvent()
 {
+    qDebug() << "enterPercentEvent called";
     if (!judgeinput())
         return;
     if (m_inputEdit->text().isEmpty()) {
@@ -249,6 +257,7 @@ void SciExpressionBar::enterPercentEvent()
 
 void SciExpressionBar::enterPointEvent()
 {
+    qDebug() << "enterPointEvent called";
     if (!judgeinput())
         return;
     replaceSelection(m_inputEdit->text());
@@ -289,6 +298,7 @@ void SciExpressionBar::enterPointEvent()
 
 void SciExpressionBar::enterBackspaceEvent()
 {
+    qDebug() << "enterBackspaceEvent called";
     QString sRegNum = "[a-z]"; //20200811去除大写字母，否则Ｅ将被看作函数
     QRegularExpression rx;
     rx.setPattern(sRegNum);
@@ -441,6 +451,7 @@ void SciExpressionBar::enterBackspaceEvent()
 
 void SciExpressionBar::enterClearEvent()
 {
+    qDebug() << "enterClearEvent called";
     bool need_addundo = !m_inputEdit->text().isEmpty();
     if (m_isAllClear) {
         m_listModel->clearItems();
@@ -467,6 +478,7 @@ void SciExpressionBar::enterClearEvent()
 
 void SciExpressionBar::enterEqualEvent()
 {
+    qDebug() << "enterEqualEvent called";
 //    m_evaluator->setVariable(QLatin1String("e"), DMath::e(), Variable::BuiltIn);
     QString exp = m_inputEdit->text();
     if (m_inputEdit->text().isEmpty()) {
@@ -479,10 +491,12 @@ void SciExpressionBar::enterEqualEvent()
     Quantity ans = m_evaluator->evalUpdateAns();
     // 20200403 bug-18971 表达式错误时输数字加等于再重新输入表达式历史记录错误表达式未被替换
     // 20200407 超过16位小数未科学计数
-    qDebug() << "m_evaluator->error()" << m_evaluator->error();
-    qDebug() << "ans" << m_inputEdit->expressionText();
+    qDebug() << "Evaluator error:" << m_evaluator->error();
+    qDebug() << "Current expression:" << m_inputEdit->expressionText();
     if (m_evaluator->error().isEmpty() && (exp.indexOf(QRegularExpression("[a-z＋－×÷/.,%()πe^!]")) != -1)) {
+        qDebug() << "Valid expression evaluated";
         if (ans.isNan() && !m_evaluator->isUserFunctionAssign()) {
+            qWarning() << "Expression evaluation error";
             m_pair.first = false;
             m_expression = exp + "＝" + tr("Expression error");
             m_listModel->updataList(m_expression, -1, true);
